@@ -273,9 +273,8 @@ def extract_staggered(infile,outfile,vars):
   output = open(outfile,"w")
   output_failed = open(outfile+'_failed_trim',"w")                          # [WM] [add]
   if vars.window_size!=-1: message("Looking for start of Tn prefix with P,Q = %d,%d (origin = %d, window size = %d)" % (P,Q,origin,vars.window_size)) # [RJ] Outputting P,Q values and origin/window size
-  else: message("Looking for start of Tn prefix within P,Q = [%d,%d]" % (P,Q))
+  else: message("Looking for start of Tn prefix within positions [%d,%d]" % (P,Q))
   tot = 0
-  #print(infile)
   if vars.barseq_catalog_out!=None:
     barcodes_file = vars.base+".barseq" # I could define this in vars
     catalog = open(barcodes_file,"w")
@@ -283,7 +282,6 @@ def extract_staggered(infile,outfile,vars):
     barseq2 = "CGTACGCTGCAGGTCGACGGCCGG"
     barseq1len,barseq2len = len(barseq1),len(barseq2)
   for line in open(infile):
-    #print(line)
     line = line.rstrip()
     if not line: continue
     if line[0]=='>': header = line; continue
@@ -1339,7 +1337,7 @@ def initialize_globals(vars, args=[], kwargs={}):
     vars.window_size = -1
     vars.primer_start_window = 0,20
     vars.window = None
-    vars.bwa_alg = "mem"
+    vars.bwa_alg = "aln" # changing from mem back to aln because of /dev/shm error on Windows machines [TRI,9/14/24]
     
     # Update defaults
     protocol = kwargs.get("protocol", "").lower()
@@ -1463,10 +1461,10 @@ def show_help():
   print('    -maxreads <INT>')
   print('    -mismatches <INT>  # when searching for constant regions in reads 1 and 2; default is 1')
   print('    -flags "<STRING>"  # args to pass to BWA')
-  print('    -bwa-alg [aln|mem]  # Default: mem. Algorithm to use for mapping reads with bwa' )
-  print('    -primer-start-window INT,INT # position in read to search for start of primer; default is [0,20]')
+  print('    -bwa-alg [aln|mem]  # Algorithm to use for mapping reads with bwa; default is \'aln\'' )
+  print('    -primer-start-window INT,INT # position in read to search for start of primer; default is: [0,20]')
   print('    -window-size INT   # automatic method to set window')
-  print('    -barseq_catalog_in|-barseq_catalog_out <file>')
+  #print('    -barseq_catalog_in|-barseq_catalog_out <file>')
   print('    -replicon-ids <comma_separated_list_of_names> # if multiple replicons/genomes/contigs/sequences were provided in -ref, give them names.')
   print('                                                  # Enter \'auto\' for autogenerated ids.')
 
