@@ -6,7 +6,7 @@ modules = glob.glob(dirname(__file__)+"/*.py")
 __all__ = [ basename(f)[:-3] for f in modules if isfile(f)]
 
 
-import gff_to_prot_table
+from pytransit.convert import gff_to_prot_table
 
 # EXPORT METHODS
 methods = {}
