@@ -23,5 +23,5 @@ import pytpp.__main__
 
 
 if __name__ == "__main__":
-    pytpp.__main__.main(sys.argv[1:])
+    pytpp.__main__.run_main()
 
